@@ -43,6 +43,13 @@ public:
         NumPages
     };
 
+protected:
+    void showEvent(QShowEvent *event) override;
+
+private:
+    void resetProtocol();
+    void restartAtEnterDetailsPage();
+
 private:
     class Private;
     kdtools::pimpl_ptr<Private> d;
